pub struct DebugChecked { /* private fields */ }Expand description
Equivalent to id::Checked when debug_assertions are enabled, but equivalent to
id::Unchecked in release.
This type is only available on platforms with 64-bit atomics.
Implementations
Sourceimpl DebugChecked
impl DebugChecked
Sourcepub unsafe fn new() -> Unique<Self>
pub unsafe fn new() -> Unique<Self>
Create a new DebugChecked. With debug_assertions enabled, this will increment a
global atomic counter. In release, this is a no-op.
Safety
The returned ID must not be compared against any other DebugChecked IDs that
originated from a different call to this function.
Note that this function is completely safe to use when debug_assertions are enabled,
although it still requires unsafe due to the behaviour in release.